@@ -29,7 +29,7 @@ from fabric.api import *
 from time import gmtime, strftime
 import os
 import sys
-from git import Repo
+#from git import Repo
 import distutils.sysconfig
 from instanceinfo import InstanceInfo
 
@@ -351,7 +351,7 @@ def build2(javaEnv, dirs, prodSecrets="False", shard="", buildApi="True", buildW
             local('aws s3 cp s3://topopps-prod-x/application-%s-s%s.yml deploy/api/config/application-%s.yml' % (javaEnv, shard, javaEnv))
         else:
             local('cp config/keyset-%s.json deploy/api/config/keyset.json' % javaEnv)
-    	    local('cp config/application-%s.yml deploy/api/config/' % javaEnv)
+            local('cp config/application-%s.yml deploy/api/config/' % javaEnv)
 
     if buildScheduler in TRUTH_VALUES:
         local('mkdir -p deploy/scheduler-worker/config')
@@ -378,8 +378,8 @@ def build2(javaEnv, dirs, prodSecrets="False", shard="", buildApi="True", buildW
         local('cp worker/target/*SNAPSHOT.jar deploy/worker/')
         if prodSecrets in TRUTH_VALUES:
             local('aws s3 cp s3://topopps-prod-x/keyset-%s-s%s.json deploy/worker/config/keyset.json' % (javaEnv, shard))
-    	    local('aws s3 cp s3://topopps-prod-x/application-%s-s%s.yml deploy/worker/config/application-%s.yml' % (javaEnv, shard, javaEnv))
-    	    local('aws s3 cp s3://topopps-prod-x/application-%s-s%s-worker.yml deploy/worker/config/application-%s-worker.yml' % (javaEnv, shard, javaEnv))
+            local('aws s3 cp s3://topopps-prod-x/application-%s-s%s.yml deploy/worker/config/application-%s.yml' % (javaEnv, shard, javaEnv))
+            local('aws s3 cp s3://topopps-prod-x/application-%s-s%s-worker.yml deploy/worker/config/application-%s-worker.yml' % (javaEnv, shard, javaEnv))
         else:
             local('cp config/keyset-%s.json deploy/worker/config/keyset.json' % javaEnv)
             local('cp config/application-%s.yml deploy/worker/config/' % javaEnv)
@@ -514,11 +514,11 @@ def remote_inflate_code(numKeep='5'):
 
 @task
 def codeversioner():
-    repo = Repo('.')
+#    repo = Repo('.')
     headcommit = repo.head.commit
     commitid = headcommit.hexsha
     versionhash = commitid
-    print versionhash
+    print (versionhash)
     with cd('/data/deploy/pending'):
         run("echo 'version=\"%s\"' > /tmp/versioner.py" % versionhash)
         cmd = 'cp /tmp/versioner.py /data/deploy/pending/versioner.py'
@@ -722,14 +722,14 @@ def restart_web(doCollectStatic=None,nginxOnly=False):
 
 @task
 @parallel
-def reload_worker(async="djangorq", doCollectStatic=None):
+def reload_worker(asyncF="djangorq", doCollectStatic=None):
     swap_code()
     if doCollectStatic in TRUTH_VALUES:
         collect_static()
 
-    if async == "djangorq":
+    if asyncF == "djangorq":
         reload_djangorq()
-    elif async == "celery":
+    elif asyncF == "celery":
         restart_celery()
     else:
         logger.info("Specified async facility not supported")
@@ -737,14 +737,14 @@ def reload_worker(async="djangorq", doCollectStatic=None):
 
 @task
 @parallel
-def restart_worker(async="djangorq", doCollectStatic=None):
+def restart_worker(asyncF="djangorq", doCollectStatic=None):
     swap_code()
     if doCollectStatic in TRUTH_VALUES:
         collect_static()
 
-    if async == "djangorq":
+    if asyncF == "djangorq":
         restart_djangorq()
-    elif async == "celery":
+    elif asyncF == "celery":
         restart_celery()
     else:
         logger.info("Specified async facility not supported")
